package Alt::Module::Path::SHARYANTO;
use base qw(Alt::Base);

our $VERSION = '0.13'; # VERSION

1;
# ABSTRACT: SHARYANTO's alternate implementation of Module::Path

__END__

=pod

=encoding UTF-8

=head1 NAME

Alt::Module::Path::SHARYANTO - SHARYANTO's alternate implementation of Module::Path

=head1 VERSION

version 0.13

=head1 RELEASE DATE

2014-04-25

=head1 DESCRIPTION

=head1 SEE ALSO

L<Alt>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Alt-Module-Path-SHARYANTO>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-Alt-Module-Path-SHARYANTO>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Alt-Module-Path-SHARYANTO>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
